==> haskell-recaptcha-0.1.0.4-312-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-50hxNJ3Vk5F3OZjeTzNn5z
key:                  recaptcha-0.1.0.4-50hxNJ3Vk5F3OZjeTzNn5z
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  588045cedf6ccfd31bf7ec5f255c81bb
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-50hxNJ3Vk5F3OZjeTzNn5z
depends:
    HTTP-4000.4.1-9S4Jm2S89YUFTulUbOJpae base-4.17.2.1
    network-3.1.4.0-ItBhIFDvz12FCCKfYobIMX
    network-uri-2.6.4.2-Ej2S5J8Z0oCB2cTGXU0OdX xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recaptcha-0.1.0.4-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-FrnR1oMp0xZ9SMjkDXIKda
key:                  recaptcha-0.1.0.4-FrnR1oMp0xZ9SMjkDXIKda
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  89d968096f76f7646bae2f71d38e76f5
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-FrnR1oMp0xZ9SMjkDXIKda
depends:
    HTTP-4000.4.1-AlxJrh8RSQCFQJop57pPCp base-4.17.2.1
    network-3.1.4.0-AsoxBmMP1pfJSzv0IgKvnl
    network-uri-2.6.4.2-JT5mjmfFxkg6DEC2jAgmZ6 xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
